@@ -33,11 +33,11 @@
 
 #define SND_LIB_MAJOR		0
 #define SND_LIB_MINOR		5
-#define SND_LIB_SUBMINOR	3
+#define SND_LIB_SUBMINOR	4
 #define SND_LIB_VERSION		((SND_LIB_MAJOR<<16)|\
 				 (SND_LIB_MINOR<<8)|\
 				  SND_LIB_SUBMINOR)
-#define SND_LIB_VERSION_STR	"0.5.3"
+#define SND_LIB_VERSION_STR	"0.5.4"
 
 /* OBSOLETE DEFINES WHICH WON'T BE IN 0.3.0 FINAL!!! */
 #define SOUNDLIB_VERSION_MAJOR		SND_LIB_MAJOR
@@ -366,7 +366,8 @@ typedef struct snd_pcm_loopback_callbacks {
 	void (*data) (void *private_data, char *buffer, size_t count);
 	void (*position_change) (void *private_data, unsigned int pos);
 	void (*format_change) (void *private_data, snd_pcm_format_t *format);
-	char *reserved[32];		/* reserved for the future use - must be NULL!!! */
+	void (*silence) (void *private_data, size_t count);
+	void *reserved[31];		/* reserved for the future use - must be NULL!!! */
 } snd_pcm_loopback_callbacks_t;
 
 int snd_pcm_loopback_open(snd_pcm_loopback_t **handle, int card, int device, int subdev, int mode);
